from coldtype.test import *

@test()
def empty(r):
    return DATPens([
        DATPen(),
        #123
    ])